from os import path
from scipy.ndimage.filters import convolve
import tecplot as tp

# 3D volume data
# This is for illustration of the mathematical process only
# and a convolution of RHO and E is probably meaningless here.
exdir = tp.session.tecplot_examples_directory()
ds = tp.data.load_tecplot(path.join(exdir, '3D_Volume', 'jetflow.plt'))

# The data looks like this
# >>> print(ds)
# Dataset:
#  Zones: ['G1']
#  Variables: ['X','Y','Z','RHO','RHO-U','RHO-V','RHO-W','E']

# Pull in the data from Tecplot into numpy arrays
g1 = ds.zone('G1')
rho = g1.variable('RHO').as_numpy_array()
rho.shape = g1.shape
e = g1.variable('E').as_numpy_array()
e.shape = g1.shape

# Do the convolution. Filter RHO with weights from E.
# see scipy documentation for details.
# http://docs.scipy.org/doc/scipy-0.16.1/reference/generated/scipy.ndimage.filters.convolve.html
result = convolve(rho, e, mode='constant', cval=0)

# We have the result as a numpy array and we want to
# push it into a new variable in the Tecplot dataset
conv_var = ds.add_variable('conv')
conv = conv_var.zone('G1')
conv[:] = result.ravel()

# Verify the data is there.
# should print:
#   [ 62688124.  73131632.  83576288. ...,  71433192.  62505044.  53579468.]
print(ds.zone('G1').variable('conv').as_numpy_array())
